@@ -1,7 +1,8 @@
-package HTML::FormFu::Constraint::File::MaxSize;
-
 use strict;
-our $VERSION = '2.03'; # VERSION
+
+package HTML::FormFu::Constraint::File::MaxSize;
+$HTML::FormFu::Constraint::File::MaxSize::VERSION = '2.06';
+# ABSTRACT: Maximum File Size Constraint
 
 use Moose;
 extends 'HTML::FormFu::Constraint::File::Size';
@@ -18,13 +19,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Constraint::File::MaxSize - Maximum File Size Constraint
 
 =head1 VERSION
 
-version 2.03
+version 2.06
 
 =head1 DESCRIPTION
 
@@ -61,4 +66,15 @@ Carl Franks C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
