@@ -1,7 +1,8 @@
-package HTML::FormFu::Constraint::Required;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
+
+package HTML::FormFu::Constraint::Required;
+$HTML::FormFu::Constraint::Required::VERSION = '2.06';
+# ABSTRACT: Required Field Constraint
 
 use Moose;
 extends 'HTML::FormFu::Constraint';
@@ -18,13 +19,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Constraint::Required - Required Field Constraint
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 DESCRIPTION
 
@@ -48,4 +53,15 @@ Sebastian Riedel, C<sri@oook.de>.
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
