@@ -1,10 +1,11 @@
-package HTML::FormFu::Deflator::CompoundDateTime;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
+
+package HTML::FormFu::Deflator::CompoundDateTime;
+$HTML::FormFu::Deflator::CompoundDateTime::VERSION = '2.06';
+# ABSTRACT: CompoundDateTime deflator
 
 use Moose;
-use MooseX::Attribute::FormFuChained;
+use MooseX::Attribute::Chained;
 extends 'HTML::FormFu::Deflator';
 
 use HTML::FormFu::Constants qw( $EMPTY_STR );
@@ -12,7 +13,7 @@ use DateTime;
 use List::Util 1.33 qw( none );
 use Carp qw( croak );
 
-has field_order => ( is => 'rw', traits => ['FormFuChained'] );
+has field_order => ( is => 'rw', traits => ['Chained'] );
 
 my @known_fields = qw( year month day hour minute second nanosecond time_zone );
 
@@ -59,13 +60,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Deflator::CompoundDateTime - CompoundDateTime deflator
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 SYNOPSIS
 
@@ -150,4 +155,15 @@ Carl Franks
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
