@@ -1,17 +1,18 @@
-package HTML::FormFu::Deflator::CompoundSplit;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
+
+package HTML::FormFu::Deflator::CompoundSplit;
+$HTML::FormFu::Deflator::CompoundSplit::VERSION = '2.06';
+# ABSTRACT: CompoundSplit deflator
 
 use Moose;
-use MooseX::Attribute::FormFuChained;
+use MooseX::Attribute::Chained;
 extends 'HTML::FormFu::Deflator';
 
 use HTML::FormFu::Constants qw( $EMPTY_STR $SPACE );
 
-has split       => ( is => 'rw', traits => ['FormFuChained'] );
-has join        => ( is => 'rw', traits => ['FormFuChained'] );
-has field_order => ( is => 'rw', traits => ['FormFuChained'] );
+has split       => ( is => 'rw', traits => ['Chained'] );
+has join        => ( is => 'rw', traits => ['Chained'] );
+has field_order => ( is => 'rw', traits => ['Chained'] );
 
 sub deflator {
     my ( $self, $value ) = @_;
@@ -78,13 +79,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Deflator::CompoundSplit - CompoundSplit deflator
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 SYNOPSIS
 
@@ -176,4 +181,15 @@ Carl Franks
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
