@@ -1,7 +1,8 @@
-package HTML::FormFu::Element::Blank;
-
 use strict;
-our $VERSION = '2.03'; # VERSION
+
+package HTML::FormFu::Element::Blank;
+$HTML::FormFu::Element::Blank::VERSION = '2.06';
+# ABSTRACT: blank element
 
 use Moose;
 
@@ -40,13 +41,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Element::Blank - blank element
 
 =head1 VERSION
 
-version 2.03
+version 2.06
 
 =head1 SEE ALSO
 
@@ -66,4 +71,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
