@@ -1,7 +1,8 @@
-package HTML::FormFu::Element::Checkbox;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
+
+package HTML::FormFu::Element::Checkbox;
+$HTML::FormFu::Element::Checkbox::VERSION = '2.06';
+# ABSTRACT: Checkbox form field
 
 use Moose;
 
@@ -19,10 +20,7 @@ after BUILD => sub {
     $self->field_type('checkbox');
     $self->value(1);
 
-    $self->multi_layout( [
-        'field',
-        'label',
-    ] );
+    $self->multi_layout( [ 'field', 'label', ] );
 
     return;
 };
@@ -48,7 +46,7 @@ sub prepare_attrs {
         ? $self->get_nested_hash_value( $form->input, $self->nested_name )
         : undef;
 
-    if (defined $value and ref $value eq 'ARRAY') {
+    if ( defined $value and ref $value eq 'ARRAY' ) {
         $value = $original if grep { $_ eq $original } @$value;
     }
 
@@ -83,13 +81,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Element::Checkbox - Checkbox form field
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 SYNOPSIS
 
@@ -133,4 +135,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
