@@ -1,10 +1,11 @@
-package HTML::FormFu::Element::ContentButton;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
+
+package HTML::FormFu::Element::ContentButton;
+$HTML::FormFu::Element::ContentButton::VERSION = '2.06';
+# ABSTRACT: Button form field containing markup
 
 use Moose;
-use MooseX::Attribute::FormFuChained;
+use MooseX::Attribute::Chained;
 extends "HTML::FormFu::Element";
 with 'HTML::FormFu::Role::Element::Field',
     'HTML::FormFu::Role::Element::SingleValueField';
@@ -17,7 +18,7 @@ has field_type => (
     is      => 'rw',
     default => 'button',
     lazy    => 1,
-    traits  => ['FormFuChained'],
+    traits  => ['Chained'],
 );
 
 after BUILD => sub {
@@ -31,8 +32,8 @@ after BUILD => sub {
 sub render_data_non_recursive {
     my ( $self, $args ) = @_;
 
-    my $render = $self->SUPER::render_data_non_recursive( {
-            field_type => $self->field_type,
+    my $render = $self->SUPER::render_data_non_recursive(
+        {   field_type => $self->field_type,
             content    => xml_escape( $self->content ),
             $args ? %$args : (),
         } );
@@ -68,13 +69,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Element::ContentButton - Button form field containing markup
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 SYNOPSIS
 
@@ -112,4 +117,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
