@@ -1,7 +1,8 @@
-package HTML::FormFu::Element::Hr;
-
 use strict;
-our $VERSION = '2.03'; # VERSION
+
+package HTML::FormFu::Element::Hr;
+$HTML::FormFu::Element::Hr::VERSION = '2.06';
+# ABSTRACT: horizontal-rule element
 
 use Moose;
 
@@ -23,13 +24,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Element::Hr - horizontal-rule element
 
 =head1 VERSION
 
-version 2.03
+version 2.06
 
 =head1 DESCRIPTION
 
@@ -52,4 +57,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
