@@ -1,9 +1,11 @@
-package HTML::FormFu::Element::Radiogroup;
-
 use strict;
-our $VERSION = '2.02'; # VERSION
+
+package HTML::FormFu::Element::Radiogroup;
+$HTML::FormFu::Element::Radiogroup::VERSION = '2.06';
+# ABSTRACT: Group of radiobutton form fields
 
 use Moose;
+use MooseX::Attribute::Chained;
 extends 'HTML::FormFu::Element::Checkboxgroup';
 
 use HTML::FormFu::Constants qw( $EMPTY_STR );
@@ -23,13 +25,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Element::Radiogroup - Group of radiobutton form fields
 
 =head1 VERSION
 
-version 2.02
+version 2.06
 
 =head1 SYNOPSIS
 
@@ -108,4 +114,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
