@@ -1,18 +1,19 @@
-package HTML::FormFu::Element::SimpleTable;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
+
+package HTML::FormFu::Element::SimpleTable;
+$HTML::FormFu::Element::SimpleTable::VERSION = '2.06';
+# ABSTRACT: simple table element
 
 use Moose;
-use MooseX::Attribute::FormFuChained;
+use MooseX::Attribute::Chained;
 extends 'HTML::FormFu::Element::Block';
 
 use HTML::FormFu::Util qw( append_xml_attribute );
 use Scalar::Util qw( reftype );
 use Carp qw( croak );
 
-has odd_class  => ( is => 'rw', traits => ['FormFuChained'] );
-has even_class => ( is => 'rw', traits => ['FormFuChained'] );
+has odd_class  => ( is => 'rw', traits => ['Chained'] );
+has even_class => ( is => 'rw', traits => ['Chained'] );
 
 after BUILD => sub {
     my $self = shift;
@@ -106,8 +107,8 @@ sub render_data_non_recursive {    # though it is really recursive
         $i++;
     }
 
-    my $render = $self->SUPER::render_data_non_recursive( {
-            elements => [ map { $_->render_data } @{ $self->_elements } ],
+    my $render = $self->SUPER::render_data_non_recursive(
+        {   elements => [ map { $_->render_data } @{ $self->_elements } ],
             $args ? %$args : (),
         } );
 
@@ -122,13 +123,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Element::SimpleTable - simple table element
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 SYNOPSIS
 
@@ -213,4 +218,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
