@@ -1,10 +1,10 @@
-package HTML::FormFu::Element::URL;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
+
+package HTML::FormFu::Element::URL;
+$HTML::FormFu::Element::URL::VERSION = '2.06';
+# ABSTRACT: HTML5 URL form field
 
 use Moose;
-use MooseX::Attribute::FormFuChained;
 
 extends 'HTML::FormFu::Element';
 
@@ -12,13 +12,13 @@ with 'HTML::FormFu::Role::Element::Input';
 
 use HTML::FormFu::Attribute qw( mk_output_accessors );
 
-has http_only  => ( is => 'rw', traits => ['FormFuChained'] );
-has https_only => ( is => 'rw', traits => ['FormFuChained'] );
+has http_only  => ( is => 'rw', traits => ['Chained'] );
+has https_only => ( is => 'rw', traits => ['Chained'] );
 
 has error_message => (
     is        => 'rw',
     predicate => 'has_message',
-    traits    => ['FormFuChained'],
+    traits    => ['Chained'],
 );
 
 has _has_auto_regex_constraint => (
@@ -37,7 +37,7 @@ after BUILD => sub {
 };
 
 sub pre_process {
-    my ( $self ) = @_;
+    my ($self) = @_;
 
     my $constraint;
 
@@ -57,29 +57,25 @@ sub pre_process {
             $scheme = 'https?';
         }
 
-        $constraint = $self->constraint({
-            type => 'Regex',
-            common => [
-                'URI',
-                'HTTP',
-                { -scheme => $scheme },
-            ],
-        });
+        $constraint = $self->constraint(
+            {   type   => 'Regex',
+                common => [ 'URI', 'HTTP', { -scheme => $scheme }, ],
+            } );
 
-        $self->_has_auto_regex_constraint( $constraint );
+        $self->_has_auto_regex_constraint($constraint);
 
         # 'pattern' attribute
-        $self->pattern( "$scheme://.*" );
+        $self->pattern("$scheme://.*");
 
     }
 
     my $message = $self->error_message;
     if ( defined $message && length $message ) {
-        $constraint->message( $message );
+        $constraint->message($message);
     }
 
     return;
-};
+}
 
 __PACKAGE__->meta->make_immutable;
 
@@ -87,13 +83,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Element::URL - HTML5 URL form field
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 SYNOPSIS
 
@@ -159,4 +159,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
