@@ -1,8 +1,7 @@
-package HTML::FormFu::Exception;
-
 use strict;
-our $VERSION = '2.03'; # VERSION
 
+package HTML::FormFu::Exception;
+$HTML::FormFu::Exception::VERSION = '2.06';
 use Moose;
 
 with 'HTML::FormFu::Role::Populate';
@@ -34,3 +33,30 @@ sub render_data_non_recursive {
 __PACKAGE__->meta->make_immutable;
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+HTML::FormFu::Exception
+
+=head1 VERSION
+
+version 2.06
+
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
