@@ -1,9 +1,8 @@
-package HTML::FormFu::FakeQuery;
-
 use strict;
-use warnings;
 
-our $VERSION = '2.05'; # VERSION
+package HTML::FormFu::FakeQuery;
+$HTML::FormFu::FakeQuery::VERSION = '2.06';
+use warnings;
 
 use Scalar::Util qw( reftype );
 use Carp qw( croak );
@@ -76,3 +75,30 @@ sub upload { }
 sub uploadInfo { {} }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+HTML::FormFu::FakeQuery
+
+=head1 VERSION
+
+version 2.06
+
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
