@@ -1,10 +1,11 @@
-package HTML::FormFu::Filter::CompoundSprintf;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
+
+package HTML::FormFu::Filter::CompoundSprintf;
+$HTML::FormFu::Filter::CompoundSprintf::VERSION = '2.06';
+# ABSTRACT: CompoundSprintf filter
 
 use Moose;
-use MooseX::Attribute::FormFuChained;
+use MooseX::Attribute::Chained;
 extends 'HTML::FormFu::Filter';
 
 with 'HTML::FormFu::Role::Filter::Compound';
@@ -12,7 +13,7 @@ with 'HTML::FormFu::Role::Filter::Compound';
 use HTML::FormFu::Constants qw( $EMPTY_STR );
 use Carp qw( croak );
 
-has sprintf => ( is => 'rw', traits => ['FormFuChained'] );
+has sprintf => ( is => 'rw', traits => ['Chained'] );
 
 sub filter {
     my ( $self, $value ) = @_;
@@ -36,13 +37,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Filter::CompoundSprintf - CompoundSprintf filter
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 SYNOPSIS
 
@@ -110,4 +115,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
