@@ -1,17 +1,18 @@
-package HTML::FormFu::Filter::Regex;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
+
+package HTML::FormFu::Filter::Regex;
+$HTML::FormFu::Filter::Regex::VERSION = '2.06';
+# ABSTRACT: regexp-based match/replace filter
 
 use Moose;
-use MooseX::Attribute::FormFuChained;
+use MooseX::Attribute::Chained;
 extends 'HTML::FormFu::Filter';
 
 use HTML::FormFu::Constants qw( $EMPTY_STR );
 
-has match   => ( is => 'rw', traits => ['FormFuChained'] );
-has replace => ( is => 'rw', traits => ['FormFuChained'] );
-has eval    => ( is => 'rw', traits => ['FormFuChained'] );
+has match   => ( is => 'rw', traits => ['Chained'] );
+has replace => ( is => 'rw', traits => ['Chained'] );
+has eval    => ( is => 'rw', traits => ['Chained'] );
 
 sub filter {
     my ( $self, $value ) = @_;
@@ -37,13 +38,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Filter::Regex - regexp-based match/replace filter
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 SYNOPSIS
 
@@ -91,4 +96,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
