@@ -1,14 +1,15 @@
-package HTML::FormFu::Filter::Split;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
+
+package HTML::FormFu::Filter::Split;
+$HTML::FormFu::Filter::Split::VERSION = '2.06';
+# ABSTRACT: filter splitting a singe value into an arrayref
 
 use Moose;
-use MooseX::Attribute::FormFuChained;
+use MooseX::Attribute::Chained;
 extends 'HTML::FormFu::Filter';
 
-has regex => ( is => 'rw', traits => ['FormFuChained'] );
-has limit => ( is => 'rw', traits => ['FormFuChained'] );
+has regex => ( is => 'rw', traits => ['Chained'] );
+has limit => ( is => 'rw', traits => ['Chained'] );
 
 sub filter {
     my ( $self, $value ) = @_;
@@ -33,13 +34,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Filter::Split - filter splitting a singe value into an arrayref
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 SYNOPSIS
 
@@ -73,4 +78,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
