@@ -1,7 +1,8 @@
-package HTML::FormFu::Filter::TrimEdges;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
+
+package HTML::FormFu::Filter::TrimEdges;
+$HTML::FormFu::Filter::TrimEdges::VERSION = '2.06';
+# ABSTRACT: filter trimming whitespace
 
 use Moose;
 extends 'HTML::FormFu::Filter';
@@ -23,13 +24,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Filter::TrimEdges - filter trimming whitespace
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 DESCRIPTION
 
@@ -48,4 +53,15 @@ This library is free software, you can redistribute it and/or modify it
 under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
