@@ -1,7 +1,8 @@
-package HTML::FormFu::Filter::UpperCase;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
+
+package HTML::FormFu::Filter::UpperCase;
+$HTML::FormFu::Filter::UpperCase::VERSION = '2.06';
+# ABSTRACT: filter transforming to upper case
 
 use Moose;
 extends 'HTML::FormFu::Filter';
@@ -20,13 +21,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Filter::UpperCase - filter transforming to upper case
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 DESCRIPTION
 
@@ -44,4 +49,15 @@ Lyo Kato, C<lyo.kato@gmail.com>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
