@@ -1,10 +1,11 @@
-package HTML::FormFu::Inflator::CompoundDateTime;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
+
+package HTML::FormFu::Inflator::CompoundDateTime;
+$HTML::FormFu::Inflator::CompoundDateTime::VERSION = '2.06';
+# ABSTRACT: CompoundDateTime inflator
 
 use Moose;
-use MooseX::Attribute::FormFuChained;
+use MooseX::Attribute::Chained;
 extends 'HTML::FormFu::Inflator';
 
 use HTML::FormFu::Constants qw( $EMPTY_STR );
@@ -14,8 +15,8 @@ use List::Util 1.33 qw( none );
 use Scalar::Util qw( reftype );
 use Carp qw( croak );
 
-has strptime    => ( is => 'rw', traits => ['FormFuChained'] );
-has field_order => ( is => 'rw', traits => ['FormFuChained'] );
+has strptime    => ( is => 'rw', traits => ['Chained'] );
+has field_order => ( is => 'rw', traits => ['Chained'] );
 
 my @known_fields = qw( year month day hour minute second nanosecond time_zone );
 
@@ -78,13 +79,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Inflator::CompoundDateTime - CompoundDateTime inflator
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 SYNOPSIS
 
@@ -195,4 +200,15 @@ Carl Franks
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
