@@ -1,10 +1,11 @@
-package HTML::FormFu::Inflator::DateTime;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
+
+package HTML::FormFu::Inflator::DateTime;
+$HTML::FormFu::Inflator::DateTime::VERSION = '2.06';
+# ABSTRACT: DateTime inflator
 
 use Moose;
-use MooseX::Attribute::FormFuChained;
+use MooseX::Attribute::Chained;
 extends 'HTML::FormFu::Inflator';
 
 use HTML::FormFu::Constants qw( $EMPTY_STR );
@@ -12,8 +13,8 @@ use DateTime::Format::Builder;
 use DateTime::Format::Strptime;
 use Scalar::Util qw( reftype );
 
-has strptime  => ( is => 'rw', traits => ['FormFuChained'] );
-has time_zone => ( is => 'rw', traits => ['FormFuChained'] );
+has strptime  => ( is => 'rw', traits => ['Chained'] );
+has time_zone => ( is => 'rw', traits => ['Chained'] );
 
 has _builder => (
     is      => 'rw',
@@ -91,13 +92,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Inflator::DateTime - DateTime inflator
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 SYNOPSIS
 
@@ -187,4 +192,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
