@@ -1,9 +1,8 @@
-package HTML::FormFu::Localize;
-
 use strict;
-use warnings;
 
-our $VERSION = '2.05'; # VERSION
+package HTML::FormFu::Localize;
+$HTML::FormFu::Localize::VERSION = '2.06';
+use warnings;
 
 use HTML::FormFu::Util qw( require_class );
 use List::Util 1.33 qw( any );
@@ -182,3 +181,30 @@ sub get_localize_object {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+HTML::FormFu::Localize
+
+=head1 VERSION
+
+version 2.06
+
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
