@@ -1,17 +1,18 @@
-package HTML::FormFu::Model;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
+
+package HTML::FormFu::Model;
+$HTML::FormFu::Model::VERSION = '2.06';
+# ABSTRACT: base class for models
 
 use Moose;
-use MooseX::Attribute::FormFuChained;
+use MooseX::Attribute::Chained;
 
 with 'HTML::FormFu::Role::HasParent';
 
 use HTML::FormFu::ObjectUtil qw( form parent );
 use Carp qw( croak );
 
-has type => ( is => 'rw', traits => ['FormFuChained'] );
+has type => ( is => 'rw', traits => ['Chained'] );
 
 sub default_values {
     croak "'default_values' method not implemented by Model class";
@@ -43,13 +44,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Model - base class for models
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 SEE ALSO
 
@@ -66,4 +71,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
