@@ -1,7 +1,8 @@
-package HTML::FormFu::Plugin::StashValid;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
+
+package HTML::FormFu::Plugin::StashValid;
+$HTML::FormFu::Plugin::StashValid::VERSION = '2.06';
+# ABSTRACT: place valid params on form stash
 
 use Moose;
 extends 'HTML::FormFu::Plugin';
@@ -25,13 +26,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Plugin::StashValid - place valid params on form stash
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 SYNOPSIS
 
@@ -74,4 +79,15 @@ Carl Franks C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
