@@ -1,10 +1,11 @@
-package HTML::FormFu::Processor;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
+
+package HTML::FormFu::Processor;
+$HTML::FormFu::Processor::VERSION = '2.06';
+# ABSTRACT: base class for constraints
 
 use Moose;
-use MooseX::Attribute::FormFuChained;
+use MooseX::Attribute::Chained;
 
 with 'HTML::FormFu::Role::NestedHashUtils',
     'HTML::FormFu::Role::HasParent',
@@ -19,7 +20,7 @@ use HTML::FormFu::ObjectUtil qw(
     name                    nested_name
     nested_names            parent );
 
-has type => ( is => 'rw', traits => ['FormFuChained'] );
+has type => ( is => 'rw', traits => ['Chained'] );
 
 __PACKAGE__->mk_output_accessors(qw( message ));
 
@@ -67,13 +68,17 @@ sub clone {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Processor - base class for constraints
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 AUTHOR
 
@@ -84,4 +89,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
