@@ -1,7 +1,8 @@
-package HTML::FormFu::QueryType::CGI;
-
 use strict;
-our $VERSION = '2.03'; # VERSION
+
+package HTML::FormFu::QueryType::CGI;
+$HTML::FormFu::QueryType::CGI::VERSION = '2.06';
+# ABSTRACT: uploaded file
 
 use Moose;
 
@@ -13,7 +14,7 @@ use Scalar::Util qw( blessed );
 sub parse_uploads {
     my ( $class, $form, $name ) = @_;
 
-    my $query  = $form->query;
+    my $query = $form->query;
     ## CGI wants you to use $query->multi_param($foo).
     ## doing so breaks CGI::Simple. So shoosh it up for now.
     local $CGI::LIST_CONTEXT_WARN = 0;
@@ -25,8 +26,8 @@ sub parse_uploads {
         if ( blessed $param ) {
             my $filename = $param;
 
-            $param = $class->new( {
-                    _param   => $param,
+            $param = $class->new(
+                {   _param   => $param,
                     filename => sprintf( "%s", $filename ),
                     parent   => $form,
 
@@ -64,13 +65,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::QueryType::CGI - uploaded file
 
 =head1 VERSION
 
-version 2.03
+version 2.06
 
 =head1 METHODS
 
@@ -119,4 +124,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
