@@ -1,7 +1,8 @@
-package HTML::FormFu::QueryType::CGI::Simple;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
+
+package HTML::FormFu::QueryType::CGI::Simple;
+$HTML::FormFu::QueryType::CGI::Simple::VERSION = '2.06';
+# ABSTRACT: uploaded file
 
 use Moose;
 
@@ -18,8 +19,8 @@ sub parse_uploads {
         if ( my $file = $query->upload($param) ) {
             my $filename = $param;
 
-            $param = $class->new( {
-                    _param   => $file,
+            $param = $class->new(
+                {   _param   => $file,
                     filename => $filename,
                     parent   => $form,
                 } );
@@ -53,13 +54,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::QueryType::CGI::Simple - uploaded file
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 METHODS
 
@@ -103,4 +108,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
