@@ -1,8 +1,7 @@
-package HTML::FormFu::Role::ContainsElementsSharedWithField;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
 
+package HTML::FormFu::Role::ContainsElementsSharedWithField;
+$HTML::FormFu::Role::ContainsElementsSharedWithField::VERSION = '2.06';
 use Moose::Role;
 
 use HTML::FormFu::Util qw(
@@ -47,8 +46,8 @@ sub _require_constraint {
 
     require_class($class);
 
-    my $constraint = $class->new( {
-            type   => $type,
+    my $constraint = $class->new(
+        {   type   => $type,
             not    => $not,
             parent => $self,
         } );
@@ -67,3 +66,30 @@ sub _require_constraint {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+HTML::FormFu::Role::ContainsElementsSharedWithField
+
+=head1 VERSION
+
+version 2.06
+
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
