@@ -1,8 +1,7 @@
-package HTML::FormFu::Role::CustomRoles;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
 
+package HTML::FormFu::Role::CustomRoles;
+$HTML::FormFu::Role::CustomRoles::VERSION = '2.06';
 use Moose::Role;
 use Moose::Util qw( ensure_all_roles );
 
@@ -24,7 +23,7 @@ sub roles {
     if ( 1 == @_ && 'ARRAY' eq ref $_[0] ) {
         @new = @{ $_[0] };
     }
-    elsif ( @_ ) {
+    elsif (@_) {
         @new = @_;
     }
 
@@ -45,10 +44,37 @@ sub roles {
 
         ensure_all_roles( $self, @roles );
 
-        $self->_roles(\@roles);
+        $self->_roles( \@roles );
     }
 
     return [@roles];
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+HTML::FormFu::Role::CustomRoles
+
+=head1 VERSION
+
+version 2.06
+
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
