@@ -1,8 +1,7 @@
-package HTML::FormFu::Role::Element::MultiElement;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
 
+package HTML::FormFu::Role::Element::MultiElement;
+$HTML::FormFu::Role::Element::MultiElement::VERSION = '2.06';
 use Moose::Role;
 
 use Carp qw( croak );
@@ -63,3 +62,30 @@ sub nested_base {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+HTML::FormFu::Role::Element::MultiElement
+
+=head1 VERSION
+
+version 2.06
+
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
