@@ -1,13 +1,12 @@
-package HTML::FormFu::Role::FormBlockAndFieldMethods;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
 
+package HTML::FormFu::Role::FormBlockAndFieldMethods;
+$HTML::FormFu::Role::FormBlockAndFieldMethods::VERSION = '2.06';
 use Moose::Role;
 
 use HTML::FormFu::Attribute qw( mk_inherited_accessors );
 
-our @MULTIFORM_SHARED = (qw(
+our @MULTIFORM_SHARED = ( qw(
         auto_id
         auto_label
         auto_label_class
@@ -19,6 +18,7 @@ our @MULTIFORM_SHARED = (qw(
         auto_container_per_error_class
         auto_error_container_class
         auto_error_container_per_error_class
+        auto_error_field_class
         auto_error_class
         auto_error_message
         auto_constraint_class
@@ -32,22 +32,43 @@ our @MULTIFORM_SHARED = (qw(
         force_errors
         repeatable_count
         locale
-));
+) );
 
-__PACKAGE__->mk_inherited_accessors( @MULTIFORM_SHARED );
+__PACKAGE__->mk_inherited_accessors(@MULTIFORM_SHARED);
 
 1;
 
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Role::FormBlockAndFieldMethods
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 DESCRIPTION
 
 Inherited Field methods.
 
+=head1 NAME
+
+HTML::FormFu::Role::FormBlockAndFieldMethods
+
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
