@@ -1,8 +1,7 @@
-package HTML::FormFu::Role::NestedHashUtils;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
 
+package HTML::FormFu::Role::NestedHashUtils;
+$HTML::FormFu::Role::NestedHashUtils::VERSION = '2.06';
 use Moose::Role;
 
 use HTML::FormFu::Util qw( split_name );
@@ -155,3 +154,30 @@ sub nested_hash_key_exists {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+HTML::FormFu::Role::NestedHashUtils
+
+=head1 VERSION
+
+version 2.06
+
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
