@@ -1,13 +1,14 @@
-package HTML::FormFu::Transformer::Callback;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
+
+package HTML::FormFu::Transformer::Callback;
+$HTML::FormFu::Transformer::Callback::VERSION = '2.06';
+# ABSTRACT: Callback transformer
 
 use Moose;
-use MooseX::Attribute::FormFuChained;
+use MooseX::Attribute::Chained;
 extends 'HTML::FormFu::Transformer';
 
-has callback => ( is => 'rw', traits => ['FormFuChained'] );
+has callback => ( is => 'rw', traits => ['Chained'] );
 
 sub transformer {
     my ( $self, $value, $params ) = @_;
@@ -28,13 +29,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Transformer::Callback - Callback transformer
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 SYNOPSIS
 
@@ -77,4 +82,15 @@ Carl Franks C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
