@@ -1,20 +1,21 @@
-package HTML::FormFu::Upload;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
+
+package HTML::FormFu::Upload;
+$HTML::FormFu::Upload::VERSION = '2.06';
+# ABSTRACT: uploaded file
 
 use Moose;
-use MooseX::Attribute::FormFuChained;
+use MooseX::Attribute::Chained;
 
 with 'HTML::FormFu::Role::Populate';
 
 use HTML::FormFu::ObjectUtil qw( form parent );
 use HTML::FormFu::UploadParam;
 
-has headers  => ( is => 'rw', traits => ['FormFuChained'] );
-has filename => ( is => 'rw', traits => ['FormFuChained'] );
-has size     => ( is => 'rw', traits => ['FormFuChained'] );
-has type     => ( is => 'rw', traits => ['FormFuChained'] );
+has headers  => ( is => 'rw', traits => ['Chained'] );
+has filename => ( is => 'rw', traits => ['Chained'] );
+has size     => ( is => 'rw', traits => ['Chained'] );
+has type     => ( is => 'rw', traits => ['Chained'] );
 
 sub BUILD { }
 
@@ -52,13 +53,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Upload - uploaded file
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 DESCRIPTION
 
@@ -106,4 +111,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
