@@ -1,10 +1,11 @@
-package HTML::FormFu::UploadParam;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
+
+package HTML::FormFu::UploadParam;
+$HTML::FormFu::UploadParam::VERSION = '2.06';
+# ABSTRACT: accessor class
 
 use Moose;
-use MooseX::Attribute::FormFuChained;
+use MooseX::Attribute::Chained;
 
 use Carp qw( croak );
 
@@ -12,8 +13,8 @@ use File::Temp qw( tempfile );
 use Scalar::Util qw( weaken );
 use Storable qw( nfreeze thaw );
 
-has param => ( is => 'rw', traits => ['FormFuChained'], required => 1 );
-has filename => ( is => 'rw', traits => ['FormFuChained'] );
+has param => ( is => 'rw', traits => ['Chained'], required => 1 );
+has filename => ( is => 'rw', traits => ['Chained'] );
 
 sub form {
     my $self = shift;
@@ -91,13 +92,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::UploadParam - accessor class
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 DESCRIPTION
 
@@ -114,4 +119,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
