@@ -1,8 +1,8 @@
-package HTML::FormFu::Util;
-
 use strict;
+
+package HTML::FormFu::Util;
+$HTML::FormFu::Util::VERSION = '2.06';
 use warnings;
-our $VERSION = '2.05'; # VERSION
 
 use HTML::FormFu::Constants qw( $SPACE );
 use HTML::FormFu::Literal;
@@ -328,7 +328,7 @@ sub _remove_subs {
             string => sub {
                 my $x = "$_[0]";
                 my $y = xml_escape("$_[1]");
-                $x        =~ s/^\Q$y\E ?//
+                $x =~ s/^\Q$y\E ?//
                     || $x =~ s/ \Q$y\E / /
                     || $x =~ s/ ?\Q$y\E$//;
                 return literal($x);
@@ -336,7 +336,7 @@ sub _remove_subs {
             literal => sub {
                 my $x = "$_[0]";
                 my $y = "$_[1]";
-                $x        =~ s/^\Q$y\E ?//
+                $x =~ s/^\Q$y\E ?//
                     || $x =~ s/ \Q$y\E / /
                     || $x =~ s/ ?\Q$y\E$//;
                 return literal($x);
@@ -345,7 +345,7 @@ sub _remove_subs {
         string => {
             string => sub {
                 my ( $x, $y ) = @_;
-                $x        =~ s/^\Q$y\E ?//
+                $x =~ s/^\Q$y\E ?//
                     || $x =~ s/ \Q$y\E / /
                     || $x =~ s/ ?\Q$y\E$//;
                 return $x;
@@ -353,7 +353,7 @@ sub _remove_subs {
             literal => sub {
                 my $x = xml_escape( $_[0] );
                 my $y = "$_[1]";
-                $x        =~ s/^\Q$y\E ?//
+                $x =~ s/^\Q$y\E ?//
                     || $x =~ s/ \Q$y\E / /
                     || $x =~ s/ ?\Q$y\E$//;
                 return literal($x);
@@ -568,3 +568,30 @@ sub _merge_array_array {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+HTML::FormFu::Util
+
+=head1 VERSION
+
+version 2.06
+
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
